---
output: 
  html_document:
    keep_md: yes
    toc: true
    toc_depth: 2
    toc_float: true
---



# README
This file provides information for data and code found in this repository to reproduce the analyses (model fitting, prediction and sampling from the posterior of the choosen model) for the associated article **Accounting for spatio-temporal distribution changes in size-structured abundance estimates for a data-limited stock of** ***Raja clavata***

&nbsp;

# General Information
- Author(s): Timo Michael Staeudle^1^, Bram Parmentier^2,3^, Jan Jaap Poos^1,4^
- Associated Manuscript: Accounting for spatio-temporal distribution changes in size-structured abundance estimates for a data-limited stock of *Raja clavata*. (DOI: https://doi.org/10.1093/icesjms/fsae106)
- Contact Email: timo.staeudle@wur.nl
- Repository DOI: 10.4121/aa23c8b5-5441-4ac9-9e02-808bbf6b872e
- Author affiliations:
  - ^1^ Aquaculture and Fisheries Group, Wageningen University and Research, the Netherlands
  - ^2^ Wildlife Ecology and Conservation Group, Wageningen University and Research, the Netherlands
  - ^3^ NIOZ, the Royal Netherlands Institute for Sea Research, the Netherlands
  - ^4^ Wageningen Marine Research, Wageningen University and Research, the Netherlands

&nbsp;

## Introduction

The associated manuscript employed Integrated-Nested Laplace Approximation (INLA) to estimate total and size-class specific abundances of *Raja clavata*, using surface area estimates of fisheries-independent survey data. It accounted for spatio-temporal changes in the population, size selectivity between survey gears, and minimizing bias from partially overlapping survey areas. Research-vessel catch data for the North Sea and Eastern English Channel was obtained from ICES database on trawl surveys (DATRAS) for *R. clavata* (WoRMS AphiaID: 105883). The processed dataset consists of hauls and catches from the International Bottom Trawl Survey (NS-IBTS) for Quarter 1 and 3, the Beam Trawl Survey (NS-BTS) for Quarter 3, and the Channel Groundfish Survey (FR-CGFS) for Quarter 4. It further contains depth, substrate and habitat types associated with haul locations, from emodnet for the study area. The data and analyses covers the period 1988-2023.

&nbsp;

## Description
- Materials and Methods: 
Please view the associated publication https://doi.org/10.1093/icesjms/fsae106 for detailed information on materials and methods.

- Processing and analysis scripts
Processed data and analysis of data was performed in R. Scripts are commented, describing steps taken.

&nbsp;

# Folder Structure 

```
## ../
## ├── code
## │   ├── 1_fit_RJC_INLA_models.html
## │   ├── 1_fit_RJC_INLA_models.md
## │   ├── 2_simulations_from_posterior_distributions_of_INLA_model.html
## │   ├── 2_simulations_from_posterior_distributions_of_INLA_model.md
## │   ├── 3_Analyse_INLA_results.html
## │   ├── 3_Analyse_INLA_results.md
## │   ├── README.html
## │   └── README.md
## ├── data
## │   └── data_RJC_INLA.RData
## └── output
##     ├── INLA_models
##     └── results
```

# Folder Contents 
**--- code**/  

|   This folder contains all scripts related to fitting INLA models and posterior sampling from the best model choosen.\    

&nbsp;

|   **--- 1_fit RJC INLA models.md (and .html):**\   
|   This file contains R code to replicate the analyses with INLA models in the associated article. It provides code to:\    

|   - Setup the analyses, such as loading R libraries, required data, etc.\   
|   - Create the mesh for the INLA models.\   
|   - Replicate and run the non-spatial (NS), spatial (S) and spatio-temporal (ST) INLA models (IM), with model numbering following Table 1 of the associated article. Model naming convention example "IM_ST10" which stands for "spatio-temporal INLA model 10".\    
|   - Model comparison & evaluation.\   
|   - Model fitting with prediction for choosen Model.\    

&nbsp;

|   **--- 2_simulations_from_posterior_distributions_of_INLA_model.md (and .html):** \     
|   This file contains R code to sample from the posterior of the best model by applying the inla.posterior.sample() function and processing the sampling results.\    

&nbsp;


|   **--- 3_Analyse_INLA_results.md (and .html):** \     
|   This file contains R code to investigate and generate results of the choosen INLA model, prediction and simulations, for the associated article.\   

&nbsp;

**--- data**/   
This folder contains all the data: \    

| **--- data_RJC_INLA.Rdata**:\   
|   - **catches_exploitability_maturity_RJC:**\   
|   Processed dataset of hauls and catches used for analyses in the associated article. This data was derived from the raw haul and catch data obtained from the ICES database on trawl surveys (DATRAS): <https://datras.ices.dk> .\    
  
|   - **bathymetry_GNS:**\    
|   Depth data obtained from European Marine Observation and Data Network (EMODnet) <https://portal.emodnet-bathymetry.eu/>. This data provided the depth information for hauls.\   

|   - **NS_EEC_poly:**\    
|   Provides the study area of the associated article as a MULTIPOLYGON geometry type (sfc_MULTIPOLYGON). required to replicate the INLA analyses: INLA model fitting, predictions and posterior distribution sampling\

|   - **NS_EEC_poly_simpl_UTM_km:**\    
|   same as NS_EEC_poly, but with simplified coastlines\

|   - **RFA_UTM_km:**\    
|   Provides polygons for roundfish area of the associated article as a MULTIPOLYGON geometry type (sfc_MULTIPOLYGON). required to replicate the INLA results\

|   - **NS_EEC_simpl_EUNIS_2021:**\
|   simple feature collection of EUNIS_2021 for study area.\

|   - **exploit_maturity_length_class_stats:**\
|   Data of exploitation_maturity/size class classes: mean weight, mean length, gear\

|   - **exploit_length_class_stats:**\
|   Data of exploitation classes: mean weight, mean length, gear\

|   - **gear_efficiency**\
|   gear efficiency data for Raja clavata obtained from Walker et al. 2017: https://doi.org/10.1093/icesjms/fsw250


&nbsp;

**--- output**/  
All output generated from the code is saved in this folder with sub-directories:\   

|   - **INLA_models**: All fitted INLA models and respective objects used for model fitting saved in a list.\
|   - **results**: Results from sampling the posterior distribution of the best model.\

&nbsp;

## Additinoal Code remarks
### Size-class classifications

Defined size classes in the associated article are exchangeable with the following exploitation and maturity categories found in the data:

-   Size class 1 = Unexploited_Immature = unexploited_immature\   
-   Size class 2 = Exploited_Immature = exploited_immature\
-   Size class 3 = Exploited_Mature = exploited_immature\

# Research Software (RS)
## RS Language

All scripts are written using R. 

&nbsp;

<!-- ## RS Information -->
<!-- Here is code to summarise version of pacakges used -->
<!-- - R version 4.2.3 -->





<!-- &nbsp; -->

## RS Installation: 

All software and libraries used to create the scripts are open source and freely available.

## RS OperatingInstructions

The scripts can be run as is when the current folder structure is maintained after download.
The scripts have pointers to the correct folders and files to be imported. All paths are relative to the parent directory.

# Data Formats

- .Rdata

&nbsp;

# Contributing 

Materials published are licensed under **CC BY-NC 4.0**.
If you find any errors within the scripts, please contact timo.staeudle@wur.nl for corrections where appropriate.
If validated, we will update corrected scripts.

&nbsp;

# Citation

The materials described here are published in 4TU.ResearchData. Please view the information at the 4TU.ResearchData DOI and the associated manuscript DOI (see under # General) to find the citation information.

&nbsp;

<!-- Here is code to zip all required files for the repository, run seperately after knitting -->



